@@ -1,3 +1,3 @@
 # __init__.py
 from region_estimators.region_estimator_factory import RegionEstimatorFactory
-#from estimation_data import EstimationData
+from region_estimators.estimation_data import EstimationData
